Release 84.0.4147.132

This commit is contained in:
csagan5 2020-08-17 17:07:38 +02:00
parent ce75c13b20
commit c65e5bbda4
31 changed files with 141 additions and 296 deletions

View file

@ -1,3 +1,9 @@
# 84.0.4147.132
* fix exit menu item not always working (thanks to @uazo, fixes https://github.com/bromite/bromite/issues/673)
* session-only cookies site settings option (thanks to @uazo, fixes https://github.com/bromite/bromite/issues/142)
* add setting to enable history on incognito mode (thanks to @uazo)
* removed old non-working site settings patches
# 84.0.4147.121
* removed Qwant search engine
* fixed zh_CN translations

View file

@ -1 +1 @@
84.0.4147.121
84.0.4147.132

View file

@ -6,7 +6,6 @@ Always-allow-partner-customisation.patch
battery_status_service-disable-more-privacy-nightmares.patch
Battery-API-return-nothing.patch
updater-disable-updater-pings.patch
prefs-only-keep-cookies-until-exit.patch
Remove-EV-certificates.patch
promo-disable-Google-promotion-fetching.patch
Disable-omission-of-URL-elements-in-Omnibox.patch
@ -57,7 +56,6 @@ Add-flags-to-disable-device-motion-orientation-APIs.patch
Disable-metrics-on-all-I-O-threads.patch
Always-respect-async-dns-flag-regardless-of-SDK-version.patch
Add-flag-to-configure-maximum-connections-per-host.patch
Add-site-settings-option-for-session-only-cookies.patch
Add-bookmark-import-export-actions.patch
Disable-promos-displayed-in-bookmarks-manager.patch
Add-an-always-incognito-mode.patch

View file

@ -17,7 +17,7 @@ See also:
diff --git a/chrome/browser/about_flags.cc b/chrome/browser/about_flags.cc
--- a/chrome/browser/about_flags.cc
+++ b/chrome/browser/about_flags.cc
@@ -4437,6 +4437,12 @@ const FeatureEntry kFeatureEntries[] = {
@@ -4441,6 +4441,12 @@ const FeatureEntry kFeatureEntries[] = {
kOsAll,
FEATURE_VALUE_TYPE(features::kEnableAmbientAuthenticationInIncognito)},

View file

@ -152,7 +152,7 @@ diff --git a/chrome/android/java/src/org/chromium/chrome/browser/ChromeActivity.
diff --git a/chrome/android/java/src/org/chromium/chrome/browser/ChromeTabbedActivity.java b/chrome/android/java/src/org/chromium/chrome/browser/ChromeTabbedActivity.java
--- a/chrome/android/java/src/org/chromium/chrome/browser/ChromeTabbedActivity.java
+++ b/chrome/android/java/src/org/chromium/chrome/browser/ChromeTabbedActivity.java
@@ -49,6 +49,7 @@ import org.chromium.base.supplier.ObservableSupplierImpl;
@@ -51,6 +51,7 @@ import org.chromium.base.supplier.OneShotCallback;
import org.chromium.base.supplier.Supplier;
import org.chromium.base.task.PostTask;
import org.chromium.chrome.R;
@ -160,7 +160,7 @@ diff --git a/chrome/android/java/src/org/chromium/chrome/browser/ChromeTabbedAct
import org.chromium.chrome.browser.IntentHandler.IntentHandlerDelegate;
import org.chromium.chrome.browser.IntentHandler.TabOpenType;
import org.chromium.chrome.browser.accessibility_tab_switcher.OverviewListLayout;
@@ -1621,8 +1622,9 @@ public class ChromeTabbedActivity
@@ -1644,8 +1645,9 @@ public class ChromeTabbedActivity
Bundle savedInstanceState = getSavedInstanceState();
// We determine the model as soon as possible so every systems get initialized coherently.
@ -370,7 +370,7 @@ diff --git a/chrome/android/java/src/org/chromium/chrome/browser/tabmodel/TabPer
diff --git a/chrome/browser/flags/android/chrome_feature_list.cc b/chrome/browser/flags/android/chrome_feature_list.cc
--- a/chrome/browser/flags/android/chrome_feature_list.cc
+++ b/chrome/browser/flags/android/chrome_feature_list.cc
@@ -338,7 +338,7 @@ const base::Feature kCCTExternalLinkHandling{"CCTExternalLinkHandling",
@@ -339,7 +339,7 @@ const base::Feature kCCTExternalLinkHandling{"CCTExternalLinkHandling",
base::FEATURE_ENABLED_BY_DEFAULT};
const base::Feature kCCTIncognito{"CCTIncognito",
@ -382,7 +382,7 @@ diff --git a/chrome/browser/flags/android/chrome_feature_list.cc b/chrome/browse
diff --git a/chrome/browser/ui/android/strings/android_chrome_strings.grd b/chrome/browser/ui/android/strings/android_chrome_strings.grd
--- a/chrome/browser/ui/android/strings/android_chrome_strings.grd
+++ b/chrome/browser/ui/android/strings/android_chrome_strings.grd
@@ -725,6 +725,13 @@ Your Google account may have other forms of browsing history like searches and a
@@ -724,6 +724,13 @@ Your Google account may have other forms of browsing history like searches and a
<message name="IDS_CLEAR_BROWSING_HISTORY_SUMMARY" desc="A text for the basic tab explaining browsing history.">
Clears history and autocompletions in the address bar.
</message>

View file

@ -97,7 +97,7 @@ diff --git a/chrome/android/java/src/org/chromium/chrome/browser/privacy/setting
diff --git a/chrome/browser/ui/android/strings/android_chrome_strings.grd b/chrome/browser/ui/android/strings/android_chrome_strings.grd
--- a/chrome/browser/ui/android/strings/android_chrome_strings.grd
+++ b/chrome/browser/ui/android/strings/android_chrome_strings.grd
@@ -3450,6 +3450,13 @@ Only you can see what your camera is looking at. The site can't see your camera'
@@ -3449,6 +3449,13 @@ Only you can see what your camera is looking at. The site can't see your camera'
<message name="IDS_NEAR_OOM_REDUCTION_DECLINE" desc="The text of the button letting the user decline the browser's intervention, so that the page can be reloaded.">
Show original
</message>

View file

@ -4,11 +4,11 @@ Subject: Add exit menu item
Corrected Exit functionality
---
chrome/android/java/res/menu/main_menu.xml | 4 ++++
.../src/org/chromium/chrome/browser/ChromeActivity.java | 5 +++++
.../chrome/browser/init/ChromeLifetimeController.java | 6 +++++-
.../browser/ui/android/strings/android_chrome_strings.grd | 3 +++
4 files changed, 17 insertions(+), 1 deletion(-)
chrome/android/java/res/menu/main_menu.xml | 4 ++++
.../src/org/chromium/chrome/browser/ChromeActivity.java | 7 +++++++
.../chrome/browser/init/ChromeLifetimeController.java | 6 +++++-
.../browser/ui/android/strings/android_chrome_strings.grd | 3 +++
4 files changed, 19 insertions(+), 1 deletion(-)
diff --git a/chrome/android/java/res/menu/main_menu.xml b/chrome/android/java/res/menu/main_menu.xml
--- a/chrome/android/java/res/menu/main_menu.xml
@ -34,8 +34,8 @@ diff --git a/chrome/android/java/res/menu/main_menu.xml b/chrome/android/java/re
diff --git a/chrome/android/java/src/org/chromium/chrome/browser/ChromeActivity.java b/chrome/android/java/src/org/chromium/chrome/browser/ChromeActivity.java
--- a/chrome/android/java/src/org/chromium/chrome/browser/ChromeActivity.java
+++ b/chrome/android/java/src/org/chromium/chrome/browser/ChromeActivity.java
@@ -1925,6 +1925,11 @@ public abstract class ChromeActivity<C extends ChromeActivityComponent>
return true;
@@ -1920,6 +1920,11 @@ public abstract class ChromeActivity<C extends ChromeActivityComponent>
RecordUserAction.record("MobileMenuSettings");
}
+ if (id == R.id.exit_id) {
@ -43,9 +43,18 @@ diff --git a/chrome/android/java/src/org/chromium/chrome/browser/ChromeActivity.
+ return true;
+ }
+
final Tab currentTab = getActivityTab();
if (id == R.id.help_id) {
if (id == R.id.update_menu_id) {
UpdateMenuItemHelper.getInstance().onMenuItemClicked(this);
return true;
@@ -1996,6 +2001,8 @@ public abstract class ChromeActivity<C extends ChromeActivityComponent>
AddToHomescreenCoordinator.showForAppMenu(
this, getWindowAndroid(), getModalDialogManager(), currentTab.getWebContents());
RecordUserAction.record("MobileMenuAddToHomescreen");
+ } else if (id == R.id.exit_id) {
+ ApplicationLifetime.terminate(false);
} else if (id == R.id.open_webapk_id) {
Context context = ContextUtils.getApplicationContext();
String packageName =
diff --git a/chrome/android/java/src/org/chromium/chrome/browser/init/ChromeLifetimeController.java b/chrome/android/java/src/org/chromium/chrome/browser/init/ChromeLifetimeController.java
--- a/chrome/android/java/src/org/chromium/chrome/browser/init/ChromeLifetimeController.java
+++ b/chrome/android/java/src/org/chromium/chrome/browser/init/ChromeLifetimeController.java
@ -65,7 +74,7 @@ diff --git a/chrome/android/java/src/org/chromium/chrome/browser/init/ChromeLife
diff --git a/chrome/browser/ui/android/strings/android_chrome_strings.grd b/chrome/browser/ui/android/strings/android_chrome_strings.grd
--- a/chrome/browser/ui/android/strings/android_chrome_strings.grd
+++ b/chrome/browser/ui/android/strings/android_chrome_strings.grd
@@ -2414,6 +2414,9 @@ To change this setting, <ph name="BEGIN_LINK">&lt;resetlink&gt;</ph>reset sync<p
@@ -2413,6 +2413,9 @@ To change this setting, <ph name="BEGIN_LINK">&lt;resetlink&gt;</ph>reset sync<p
<message name="IDS_MENU_SETTINGS" desc="Menu item for opening browser settings. [CHAR-LIMIT=27]">
Settings
</message>
@ -75,3 +84,6 @@ diff --git a/chrome/browser/ui/android/strings/android_chrome_strings.grd b/chro
<message name="IDS_MENU_CLOSE_ALL_TABS" desc="Menu item for closing all open tabs. [CHAR-LIMIT=27]">
Close all tabs
</message>
--
2.17.1

View file

@ -38,9 +38,9 @@ diff --git a/chrome/browser/about_flags.cc b/chrome/browser/about_flags.cc
+ {"max-connections-per-host", flag_descriptions::kMaxConnectionsPerHostName,
+ flag_descriptions::kMaxConnectionsPerHostDescription, kOsAll,
+ MULTI_VALUE_TYPE(kMaxConnectionsPerHostChoices)},
#endif // OS_ANDROID
{"disallow-doc-written-script-loads",
flag_descriptions::kDisallowDocWrittenScriptsUiName,
{"reengagement-notification",
flag_descriptions::kReengagementNotificationName,
flag_descriptions::kReengagementNotificationDescription, kOsAndroid,
diff --git a/chrome/browser/flag_descriptions.cc b/chrome/browser/flag_descriptions.cc
--- a/chrome/browser/flag_descriptions.cc
+++ b/chrome/browser/flag_descriptions.cc

View file

@ -16,7 +16,7 @@ Subject: Add flag to disable IPv6 probes
diff --git a/chrome/browser/about_flags.cc b/chrome/browser/about_flags.cc
--- a/chrome/browser/about_flags.cc
+++ b/chrome/browser/about_flags.cc
@@ -3709,6 +3709,11 @@ const FeatureEntry kFeatureEntries[] = {
@@ -3713,6 +3713,11 @@ const FeatureEntry kFeatureEntries[] = {
FEATURE_VALUE_TYPE(features::kDirectManipulationStylus)},
#endif // defined(OS_WIN) || defined(OS_MACOSX) || defined(OS_LINUX)

View file

@ -212,7 +212,7 @@ old mode 100644
new mode 100755
--- a/chrome/browser/ui/android/strings/android_chrome_strings.grd
+++ b/chrome/browser/ui/android/strings/android_chrome_strings.grd
@@ -746,6 +746,12 @@ Your Google account may have other forms of browsing history like searches and a
@@ -745,6 +745,12 @@ Your Google account may have other forms of browsing history like searches and a
<message name="IDS_ALWAYS_INCOGNITO_SUMMARY" desc="Summary for always incognito mode">
Opens links in incognito tabs when you click on new tab or on a link
</message>
@ -230,7 +230,7 @@ old mode 100644
new mode 100755
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_it.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_it.xtb
@@ -1011,4 +1011,6 @@ Ad esempio, alcuni siti web potrebbero rispondere alla richiesta mostrando annun
@@ -1017,4 +1017,6 @@ Ad esempio, alcuni siti web potrebbero rispondere alla richiesta mostrando annun
<translation id="666268767214822976">Utilizza un servizio di previsione per visualizzare query correlate e siti web popolari durante la digitazione nella barra degli indirizzi</translation>
<translation id="8283853025636624853">Sincronizzazione con <ph name="SYNC_ACCOUNT_USER_NAME" /></translation>
<translation id="8981454092730389528">Gestione attività di Google</translation>

View file

@ -40,7 +40,7 @@ diff --git a/chrome/android/java/res/menu/main_menu.xml b/chrome/android/java/re
diff --git a/chrome/android/java/src/org/chromium/chrome/browser/ChromeActivity.java b/chrome/android/java/src/org/chromium/chrome/browser/ChromeActivity.java
--- a/chrome/android/java/src/org/chromium/chrome/browser/ChromeActivity.java
+++ b/chrome/android/java/src/org/chromium/chrome/browser/ChromeActivity.java
@@ -2005,6 +2005,8 @@ public abstract class ChromeActivity<C extends ChromeActivityComponent>
@@ -2010,6 +2010,8 @@ public abstract class ChromeActivity<C extends ChromeActivityComponent>
} catch (ActivityNotFoundException e) {
Toast.makeText(context, R.string.open_webapk_failed, Toast.LENGTH_SHORT).show();
}
@ -52,7 +52,7 @@ diff --git a/chrome/android/java/src/org/chromium/chrome/browser/ChromeActivity.
diff --git a/chrome/android/java/src/org/chromium/chrome/browser/ChromeTabbedActivity.java b/chrome/android/java/src/org/chromium/chrome/browser/ChromeTabbedActivity.java
--- a/chrome/android/java/src/org/chromium/chrome/browser/ChromeTabbedActivity.java
+++ b/chrome/android/java/src/org/chromium/chrome/browser/ChromeTabbedActivity.java
@@ -1815,6 +1815,8 @@ public class ChromeTabbedActivity
@@ -1838,6 +1838,8 @@ public class ChromeTabbedActivity
NewTabPageUma.recordAction(NewTabPageUma.ACTION_OPENED_DOWNLOADS_MANAGER);
}
RecordUserAction.record("MobileMenuDownloadManager");
@ -106,7 +106,7 @@ diff --git a/chrome/android/java/src/org/chromium/chrome/browser/customtabs/Cust
diff --git a/chrome/browser/ui/android/strings/android_chrome_strings.grd b/chrome/browser/ui/android/strings/android_chrome_strings.grd
--- a/chrome/browser/ui/android/strings/android_chrome_strings.grd
+++ b/chrome/browser/ui/android/strings/android_chrome_strings.grd
@@ -310,6 +310,9 @@ CHAR-LIMIT guidelines:
@@ -309,6 +309,9 @@ CHAR-LIMIT guidelines:
<message name="IDS_SERVICES_CATEGORY_TITLE" desc="Title for the group of preferences that control non-personalized Google services. This group contains preferences for data that is not tied to user's Google Account.">
Other Google services
</message>

View file

@ -49,7 +49,7 @@ diff --git a/chrome/android/chrome_java_resources.gni b/chrome/android/chrome_ja
diff --git a/chrome/android/chrome_java_sources.gni b/chrome/android/chrome_java_sources.gni
--- a/chrome/android/chrome_java_sources.gni
+++ b/chrome/android/chrome_java_sources.gni
@@ -1319,6 +1319,8 @@ chrome_java_sources = [
@@ -1321,6 +1321,8 @@ chrome_java_sources = [
"java/src/org/chromium/chrome/browser/photo_picker/DecodeVideoTask.java",
"java/src/org/chromium/chrome/browser/photo_picker/DecoderService.java",
"java/src/org/chromium/chrome/browser/photo_picker/DecoderServiceHost.java",
@ -449,7 +449,7 @@ diff --git a/chrome/browser/net/system_network_context_manager.cc b/chrome/brows
diff --git a/chrome/browser/ui/android/strings/android_chrome_strings.grd b/chrome/browser/ui/android/strings/android_chrome_strings.grd
--- a/chrome/browser/ui/android/strings/android_chrome_strings.grd
+++ b/chrome/browser/ui/android/strings/android_chrome_strings.grd
@@ -1826,6 +1826,20 @@ To change this setting, <ph name="BEGIN_LINK">&lt;resetlink&gt;</ph>reset sync<p
@@ -1825,6 +1825,20 @@ To change this setting, <ph name="BEGIN_LINK">&lt;resetlink&gt;</ph>reset sync<p
Work profile
</message>

View file

@ -41,7 +41,7 @@ diff --git a/chrome/android/java/res/xml/privacy_preferences.xml b/chrome/androi
diff --git a/chrome/android/java/src/org/chromium/chrome/browser/ChromeTabbedActivity.java b/chrome/android/java/src/org/chromium/chrome/browser/ChromeTabbedActivity.java
--- a/chrome/android/java/src/org/chromium/chrome/browser/ChromeTabbedActivity.java
+++ b/chrome/android/java/src/org/chromium/chrome/browser/ChromeTabbedActivity.java
@@ -1150,8 +1150,10 @@ public class ChromeTabbedActivity
@@ -1173,8 +1173,10 @@ public class ChromeTabbedActivity
boolean hadCipherData =
CipherFactory.getInstance().restoreFromBundle(getSavedInstanceState());
@ -106,7 +106,7 @@ diff --git a/chrome/android/java/src/org/chromium/chrome/browser/privacy/setting
diff --git a/chrome/browser/ui/android/strings/android_chrome_strings.grd b/chrome/browser/ui/android/strings/android_chrome_strings.grd
--- a/chrome/browser/ui/android/strings/android_chrome_strings.grd
+++ b/chrome/browser/ui/android/strings/android_chrome_strings.grd
@@ -3197,6 +3197,12 @@ Only you can see what your camera is looking at. The site can't see your camera'
@@ -3196,6 +3196,12 @@ Only you can see what your camera is looking at. The site can't see your camera'
<message name="IDS_CONTEXTMENU_IMAGE_TITLE" desc="The title of a context menu tab when the item pressed contains more than one type. This indicates that all the actions are related to the image.">
IMAGE
</message>

View file

@ -1,147 +0,0 @@
From: csagan5 <32685696+csagan5@users.noreply.github.com>
Date: Tue, 28 Aug 2018 23:27:23 +0200
Subject: Add site settings option for session-only cookies
---
.../java/res/xml/website_preferences.xml | 7 ++++
.../site_settings/SingleCategorySettings.java | 37 ++++++++++++++++++-
.../strings/android/site_settings.grdp | 6 +++
3 files changed, 49 insertions(+), 1 deletion(-)
diff --git a/components/browser_ui/site_settings/android/java/res/xml/website_preferences.xml b/components/browser_ui/site_settings/android/java/res/xml/website_preferences.xml
--- a/components/browser_ui/site_settings/android/java/res/xml/website_preferences.xml
+++ b/components/browser_ui/site_settings/android/java/res/xml/website_preferences.xml
@@ -40,6 +40,13 @@
android:title="@string/website_settings_category_notifications_quiet"
android:defaultValue="false"
android:persistent="false" />
+ <!-- A toggle for cookies to be saved only until session exit, only shown for the Cookies category. -->
+ <org.chromium.components.browser_ui.settings.ChromeBaseCheckBoxPreference
+ android:key="cookies_session_only"
+ android:title="@string/allow_cookies_session_only_title"
+ android:summary="@string/allow_cookies_session_only_summary"
+ android:defaultValue="true"
+ android:persistent="false" />
<!-- A toggle for enabling vibration in notifications. -->
<org.chromium.components.browser_ui.settings.ChromeBaseCheckBoxPreference
android:key="notifications_vibrate"
diff --git a/components/browser_ui/strings/android/site_settings.grdp b/components/browser_ui/strings/android/site_settings.grdp
--- a/components/browser_ui/strings/android/site_settings.grdp
+++ b/components/browser_ui/strings/android/site_settings.grdp
@@ -27,6 +27,12 @@
<message name="IDS_WEBSITE_SETTINGS_USE_CAMERA" desc="The category filter 'Camera' for site settings.">
Camera
</message>
+ <message name="IDS_ALLOW_COOKIES_SESSION_ONLY_TITLE" desc="Title for Allow Cookies Session Only preference">
+ Keep cookies only until you quit your browser
+ </message>
+ <message name="IDS_ALLOW_COOKIES_SESSION_ONLY_SUMMARY" desc="Summary text for Allow Session Only Cookies preference">
+ When enabled, all cookies will be erased when the browsing session is over
+ </message>
<message name="IDS_CLIPBOARD_PERMISSION_TITLE" desc="Title of the permission to read from clipboard [CHAR-LIMIT=32]">
Clipboard
</message>
--
2.17.1

View file

@ -45,7 +45,7 @@ diff --git a/chrome/android/chrome_java_resources.gni b/chrome/android/chrome_ja
diff --git a/chrome/android/chrome_java_sources.gni b/chrome/android/chrome_java_sources.gni
--- a/chrome/android/chrome_java_sources.gni
+++ b/chrome/android/chrome_java_sources.gni
@@ -1371,6 +1371,8 @@ chrome_java_sources = [
@@ -1374,6 +1374,8 @@ chrome_java_sources = [
"java/src/org/chromium/chrome/browser/searchwidget/SearchWidgetProvider.java",
"java/src/org/chromium/chrome/browser/send_tab_to_self/DevicePickerBottomSheetAdapter.java",
"java/src/org/chromium/chrome/browser/send_tab_to_self/DevicePickerBottomSheetContent.java",
@ -497,7 +497,7 @@ diff --git a/chrome/browser/net/stub_resolver_config_reader.cc b/chrome/browser/
diff --git a/chrome/browser/ui/android/strings/android_chrome_strings.grd b/chrome/browser/ui/android/strings/android_chrome_strings.grd
--- a/chrome/browser/ui/android/strings/android_chrome_strings.grd
+++ b/chrome/browser/ui/android/strings/android_chrome_strings.grd
@@ -581,6 +581,17 @@ CHAR-LIMIT guidelines:
@@ -580,6 +580,17 @@ CHAR-LIMIT guidelines:
Chrome Passwords
</message>

View file

@ -881,7 +881,7 @@ diff --git a/chrome/android/java/src/org/chromium/chrome/browser/ChromeStringCon
diff --git a/chrome/android/java/src/org/chromium/chrome/browser/ChromeTabbedActivity.java b/chrome/android/java/src/org/chromium/chrome/browser/ChromeTabbedActivity.java
--- a/chrome/android/java/src/org/chromium/chrome/browser/ChromeTabbedActivity.java
+++ b/chrome/android/java/src/org/chromium/chrome/browser/ChromeTabbedActivity.java
@@ -185,7 +185,7 @@ public class ChromeTabbedActivity
@@ -190,7 +190,7 @@ public class ChromeTabbedActivity
extends ChromeActivity<ChromeActivityComponent> implements AccessibilityUtil.Observer {
private static final String TAG = "ChromeTabbedActivity";
@ -1060,7 +1060,7 @@ diff --git a/chrome/browser/about_flags.cc b/chrome/browser/about_flags.cc
#if !defined(OS_ANDROID)
{"load-media-router-component-extension",
flag_descriptions::kLoadMediaRouterComponentExtensionName,
@@ -3000,7 +3000,7 @@ const FeatureEntry kFeatureEntries[] = {
@@ -3004,7 +3004,7 @@ const FeatureEntry kFeatureEntries[] = {
flag_descriptions::kSetMarketUrlForTestingName,
flag_descriptions::kSetMarketUrlForTestingDescription, kOsAndroid,
SINGLE_VALUE_TYPE_AND_VALUE(switches::kMarketUrlForTesting,
@ -9240,7 +9240,7 @@ diff --git a/chrome/common/url_constants.cc b/chrome/common/url_constants.cc
diff --git a/chrome/credential_provider/gaiacp/gaia_credential_base.cc b/chrome/credential_provider/gaiacp/gaia_credential_base.cc
--- a/chrome/credential_provider/gaiacp/gaia_credential_base.cc
+++ b/chrome/credential_provider/gaiacp/gaia_credential_base.cc
@@ -80,7 +80,7 @@ constexpr char kGetAccessTokenBodyWithScopeFormat[] =
@@ -82,7 +82,7 @@ constexpr char kGetAccessTokenBodyWithScopeFormat[] =
constexpr wchar_t kRegCloudAssociation[] = L"enable_cloud_association";
// The access scopes should be separated by single space.
constexpr char kAccessScopes[] =
@ -9249,7 +9249,7 @@ diff --git a/chrome/credential_provider/gaiacp/gaia_credential_base.cc b/chrome/
constexpr int kHttpTimeout = 3000; // in milliseconds
// Names of keys used to fetch the custom attributes from google admin sdk
@@ -147,7 +147,7 @@ HRESULT GetExistingAccountMappingFromCD(
@@ -156,7 +156,7 @@ HRESULT GetExistingAccountMappingFromCD(
std::string escape_url_encoded_email =
net::EscapeUrlEncodedData(base::UTF16ToUTF8(email), true);
std::string get_cd_user_url = base::StringPrintf(
@ -9258,7 +9258,7 @@ diff --git a/chrome/credential_provider/gaiacp/gaia_credential_base.cc b/chrome/
"%s?projection=full&viewType=domain_public",
escape_url_encoded_email.c_str());
LOGFN(VERBOSE) << "Encoded URL : " << get_cd_user_url;
@@ -456,9 +456,9 @@ HRESULT MakeUsernameForAccount(const base::Value& result,
@@ -465,9 +465,9 @@ HRESULT MakeUsernameForAccount(const base::Value& result,
// Determine if the email is a consumer domain (gmail.com or googlemail.com).
base::string16 email = GetDictString(result, kKeyEmail);
std::transform(email.begin(), email.end(), email.begin(), ::tolower);

View file

@ -84,7 +84,7 @@ diff --git a/chrome/android/BUILD.gn b/chrome/android/BUILD.gn
diff --git a/chrome/android/chrome_java_sources.gni b/chrome/android/chrome_java_sources.gni
--- a/chrome/android/chrome_java_sources.gni
+++ b/chrome/android/chrome_java_sources.gni
@@ -1355,7 +1355,6 @@ chrome_java_sources = [
@@ -1358,7 +1358,6 @@ chrome_java_sources = [
"java/src/org/chromium/chrome/browser/resources/ResourceMapper.java",
"java/src/org/chromium/chrome/browser/rlz/RevenueStats.java",
"java/src/org/chromium/chrome/browser/rlz/RlzPingHandler.java",
@ -1963,7 +1963,7 @@ diff --git a/chrome/browser/ui/BUILD.gn b/chrome/browser/ui/BUILD.gn
diff --git a/chrome/browser/ui/android/strings/android_chrome_strings.grd b/chrome/browser/ui/android/strings/android_chrome_strings.grd
--- a/chrome/browser/ui/android/strings/android_chrome_strings.grd
+++ b/chrome/browser/ui/android/strings/android_chrome_strings.grd
@@ -328,12 +328,6 @@ CHAR-LIMIT guidelines:
@@ -327,12 +327,6 @@ CHAR-LIMIT guidelines:
<message name="IDS_PRELOAD_PAGES_SUMMARY" desc="Summary for a checkbox in Settings that controls pages preloading and informs the user about the data shared by this feature.">
Uses cookies to remember your preferences, even if you don't visit those pages
</message>
@ -1976,7 +1976,7 @@ diff --git a/chrome/browser/ui/android/strings/android_chrome_strings.grd b/chro
<message name="IDS_URL_KEYED_ANONYMIZED_DATA_TITLE" desc="Title for a checkbox in Settings that controls non-personalized URL collection and informs the user about the data shared by this feature.">
Make searches and browsing better
</message>
@@ -343,12 +337,6 @@ CHAR-LIMIT guidelines:
@@ -342,12 +336,6 @@ CHAR-LIMIT guidelines:
<message name="IDS_PRIVACY_SYNC_AND_SERVICES_LINK" desc="The text for Privacy preferences that is shown after all preference rows.">
For more settings that relate to privacy, security, and data collection, see <ph name="BEGIN_LINK">&lt;link&gt;</ph>Sync and Google services<ph name="END_LINK">&lt;/link&gt;</ph>
</message>
@ -1989,7 +1989,7 @@ diff --git a/chrome/browser/ui/android/strings/android_chrome_strings.grd b/chro
<message name="IDS_CANCEL_SYNC_DIALOG_TITLE" desc="The title of a dialog that is shown when users tries closing 'Sync and Google services' preferences without confirming the changes.">
Cancel sync?
</message>
@@ -672,30 +660,12 @@ CHAR-LIMIT guidelines:
@@ -671,30 +659,12 @@ CHAR-LIMIT guidelines:
<message name="IDS_PREFS_PRIVACY" desc="Title for the Privacy preferences. [CHAR-LIMIT=32]">
Privacy
</message>
@ -2020,7 +2020,7 @@ diff --git a/chrome/browser/ui/android/strings/android_chrome_strings.grd b/chro
<message name="IDS_CONTEXTUAL_SEARCH_TITLE" desc="Name for the Contextual Search feature, which allows users to search for a term in a web page by tapping on it.">
Touch to Search
</message>
@@ -3497,9 +3467,6 @@ Only you can see what your camera is looking at. The site can't see your camera'
@@ -3496,9 +3466,6 @@ Only you can see what your camera is looking at. The site can't see your camera'
<message name="IDS_USAGE_STATS_CONSENT_PROMPT" desc="Consent prompt when authorizing Digital Wellbeing to access Chrome usage data">
You can see sites you visit in Chrome and set timers for them.\n\nGoogle gets info about the sites you set timers for and how long you visit them. This info is used to make Digital Wellbeing better.
</message>

View file

@ -15,7 +15,7 @@ leak information through the TextClassifier set by OEM, if any
diff --git a/chrome/browser/flags/android/chrome_feature_list.cc b/chrome/browser/flags/android/chrome_feature_list.cc
--- a/chrome/browser/flags/android/chrome_feature_list.cc
+++ b/chrome/browser/flags/android/chrome_feature_list.cc
@@ -381,7 +381,7 @@ const base::Feature kChromeSharingHubV15{"ChromeSharingHubV15",
@@ -382,7 +382,7 @@ const base::Feature kChromeSharingHubV15{"ChromeSharingHubV15",
base::FEATURE_DISABLED_BY_DEFAULT};
const base::Feature kChromeSmartSelection{"ChromeSmartSelection",

View file

@ -13,7 +13,7 @@ Subject: Do not compile QR code sharing
diff --git a/chrome/android/java/AndroidManifest.xml b/chrome/android/java/AndroidManifest.xml
--- a/chrome/android/java/AndroidManifest.xml
+++ b/chrome/android/java/AndroidManifest.xml
@@ -749,22 +749,6 @@ by a child template that "extends" this file.
@@ -755,22 +755,6 @@ by a child template that "extends" this file.
</intent-filter>
</activity>

View file

@ -15,7 +15,7 @@ Expose show-legacy-tls-warnings flag on Android as well
diff --git a/chrome/browser/about_flags.cc b/chrome/browser/about_flags.cc
--- a/chrome/browser/about_flags.cc
+++ b/chrome/browser/about_flags.cc
@@ -5269,11 +5269,9 @@ const FeatureEntry kFeatureEntries[] = {
@@ -5273,11 +5273,9 @@ const FeatureEntry kFeatureEntries[] = {
FEATURE_VALUE_TYPE(features::kElasticOverscrollWin)},
#endif

View file

@ -104,7 +104,7 @@ diff --git a/chrome/android/features/media_router/java/src/org/chromium/chrome/b
diff --git a/chrome/android/java/AndroidManifest.xml b/chrome/android/java/AndroidManifest.xml
--- a/chrome/android/java/AndroidManifest.xml
+++ b/chrome/android/java/AndroidManifest.xml
@@ -766,15 +766,6 @@ by a child template that "extends" this file.
@@ -772,15 +772,6 @@ by a child template that "extends" this file.
</intent-filter>
</activity>

View file

@ -1455,7 +1455,7 @@ diff --git a/chrome/android/java/AndroidManifest.xml b/chrome/android/java/Andro
<!-- Note: All activities directly or indirectly derived from ChromeActivity
must specify android:hardwareAccelerated="false".
@@ -692,16 +686,6 @@ by a child template that "extends" this file.
@@ -698,16 +692,6 @@ by a child template that "extends" this file.
</intent-filter>
</activity>
@ -1472,7 +1472,7 @@ diff --git a/chrome/android/java/AndroidManifest.xml b/chrome/android/java/Andro
<!-- This activity is used to restart the main Chrome process. Should never be exported. -->
<activity android:name="org.chromium.chrome.browser.BrowserRestartActivity"
android:launchMode="singleInstance"
@@ -1130,18 +1114,6 @@ by a child template that "extends" this file.
@@ -1136,18 +1120,6 @@ by a child template that "extends" this file.
{% endif %}
{% block extra_application_definitions %}

View file

@ -52,7 +52,7 @@ diff --git a/chrome/android/BUILD.gn b/chrome/android/BUILD.gn
diff --git a/chrome/android/chrome_java_sources.gni b/chrome/android/chrome_java_sources.gni
--- a/chrome/android/chrome_java_sources.gni
+++ b/chrome/android/chrome_java_sources.gni
@@ -1777,9 +1777,6 @@ chrome_java_sources = [
@@ -1780,9 +1780,6 @@ chrome_java_sources = [
"java/src/org/chromium/chrome/browser/webapps/dependency_injection/WebappActivityModule.java",
"java/src/org/chromium/chrome/browser/webauth/AuthenticatorFactory.java",
"java/src/org/chromium/chrome/browser/webauth/AuthenticatorImpl.java",

View file

@ -25,7 +25,7 @@ diff --git a/chrome/android/java/res/menu/main_menu.xml b/chrome/android/java/re
diff --git a/chrome/android/java/src/org/chromium/chrome/browser/ChromeActivity.java b/chrome/android/java/src/org/chromium/chrome/browser/ChromeActivity.java
--- a/chrome/android/java/src/org/chromium/chrome/browser/ChromeActivity.java
+++ b/chrome/android/java/src/org/chromium/chrome/browser/ChromeActivity.java
@@ -1927,15 +1927,6 @@ public abstract class ChromeActivity<C extends ChromeActivityComponent>
@@ -1932,15 +1932,6 @@ public abstract class ChromeActivity<C extends ChromeActivityComponent>
final Tab currentTab = getActivityTab();

View file

@ -82,7 +82,7 @@ diff --git a/chrome/android/java/AndroidManifest.xml b/chrome/android/java/Andro
{% block extra_uses_permissions %}
{% endblock %}
@@ -890,16 +882,6 @@ by a child template that "extends" this file.
@@ -896,16 +888,6 @@ by a child template that "extends" this file.
android:resource="@xml/file_paths" />
</provider>
@ -99,7 +99,7 @@ diff --git a/chrome/android/java/AndroidManifest.xml b/chrome/android/java/Andro
<!-- Broadcast receiver that will be notified of account changes -->
<receiver android:name="org.chromium.chrome.browser.services.AccountsChangedReceiver">
<intent-filter>
@@ -1007,16 +989,6 @@ by a child template that "extends" this file.
@@ -1013,16 +995,6 @@ by a child template that "extends" this file.
<service android:name="org.chromium.chrome.browser.services.gcm.InvalidationGcmUpstreamSender"
android:exported="false"/>
@ -678,7 +678,7 @@ diff --git a/chrome/browser/android/signin/signin_manager_android.cc b/chrome/br
diff --git a/chrome/browser/ui/android/strings/android_chrome_strings.grd b/chrome/browser/ui/android/strings/android_chrome_strings.grd
--- a/chrome/browser/ui/android/strings/android_chrome_strings.grd
+++ b/chrome/browser/ui/android/strings/android_chrome_strings.grd
@@ -264,18 +264,9 @@ CHAR-LIMIT guidelines:
@@ -263,18 +263,9 @@ CHAR-LIMIT guidelines:
</message>
<!-- Sign-in, sync and personalization preferences -->
@ -697,7 +697,7 @@ diff --git a/chrome/browser/ui/android/strings/android_chrome_strings.grd b/chro
<message name="IDS_SIGNIN_PREF_SUMMARY" desc="Summary for the entry in Settings to sign in to Chrome, explaining benefits of signing in.">
Sync and personalize across devices
</message>
@@ -334,9 +325,6 @@ CHAR-LIMIT guidelines:
@@ -333,9 +324,6 @@ CHAR-LIMIT guidelines:
<message name="IDS_URL_KEYED_ANONYMIZED_DATA_SUMMARY" desc="Summary for a checkbox in Settings that controls non-personalized URL collection and informs the user about the data shared by this feature.">
Sends URLs of pages you visit to Google
</message>
@ -707,7 +707,7 @@ diff --git a/chrome/browser/ui/android/strings/android_chrome_strings.grd b/chro
<message name="IDS_CANCEL_SYNC_DIALOG_TITLE" desc="The title of a dialog that is shown when users tries closing 'Sync and Google services' preferences without confirming the changes.">
Cancel sync?
</message>
@@ -872,9 +860,6 @@ Your Google account may have other forms of browsing history like searches and a
@@ -871,9 +859,6 @@ Your Google account may have other forms of browsing history like searches and a
<message name="IDS_DATA_REDUCTION_DESCRIPTION_LITE_MODE" desc="Text describing how the Lite mode feature works. Seen only before the user has enabled the feature.">
When Lite mode is on, Chrome uses Google servers to make pages load faster. Lite mode rewrites very slow pages to load only essential content. Lite mode does not apply to Incognito tabs.
</message>

View file

@ -64,7 +64,7 @@ diff --git a/chrome/browser/flag-metadata.json b/chrome/browser/flag-metadata.js
diff --git a/chrome/browser/flag_descriptions.cc b/chrome/browser/flag_descriptions.cc
--- a/chrome/browser/flag_descriptions.cc
+++ b/chrome/browser/flag_descriptions.cc
@@ -2752,6 +2752,11 @@ const char kSafeBrowsingUseLocalBlacklistsV2Description[] =
@@ -2758,6 +2758,11 @@ const char kSafeBrowsingUseLocalBlacklistsV2Description[] =
"process to check the Safe Browsing reputation of URLs without calling "
"into GmsCore for every URL.";
@ -79,7 +79,7 @@ diff --git a/chrome/browser/flag_descriptions.cc b/chrome/browser/flag_descripti
diff --git a/chrome/browser/flag_descriptions.h b/chrome/browser/flag_descriptions.h
--- a/chrome/browser/flag_descriptions.h
+++ b/chrome/browser/flag_descriptions.h
@@ -1604,6 +1604,9 @@ extern const char kReportFeedUserActionsDescription[];
@@ -1607,6 +1607,9 @@ extern const char kReportFeedUserActionsDescription[];
extern const char kSafeBrowsingUseLocalBlacklistsV2Name[];
extern const char kSafeBrowsingUseLocalBlacklistsV2Description[];
@ -92,7 +92,7 @@ diff --git a/chrome/browser/flag_descriptions.h b/chrome/browser/flag_descriptio
diff --git a/chrome/browser/flags/android/chrome_feature_list.cc b/chrome/browser/flags/android/chrome_feature_list.cc
--- a/chrome/browser/flags/android/chrome_feature_list.cc
+++ b/chrome/browser/flags/android/chrome_feature_list.cc
@@ -182,6 +182,7 @@ const base::Feature* kFeaturesExposedToJava[] = {
@@ -183,6 +183,7 @@ const base::Feature* kFeaturesExposedToJava[] = {
&kRelatedSearches,
&kRevampedContextMenu,
&kScrollToExpandPaymentHandler,
@ -100,7 +100,7 @@ diff --git a/chrome/browser/flags/android/chrome_feature_list.cc b/chrome/browse
&kSearchEnginePromoExistingDevice,
&kSearchEnginePromoNewDevice,
&kServiceManagerForBackgroundPrefetch,
@@ -551,6 +552,9 @@ const base::Feature kRevampedContextMenu{"RevampedContextMenu",
@@ -555,6 +556,9 @@ const base::Feature kRevampedContextMenu{"RevampedContextMenu",
const base::Feature kScrollToExpandPaymentHandler{
"ScrollToExpandPaymentHandler", base::FEATURE_DISABLED_BY_DEFAULT};
@ -113,7 +113,7 @@ diff --git a/chrome/browser/flags/android/chrome_feature_list.cc b/chrome/browse
diff --git a/chrome/browser/flags/android/chrome_feature_list.h b/chrome/browser/flags/android/chrome_feature_list.h
--- a/chrome/browser/flags/android/chrome_feature_list.h
+++ b/chrome/browser/flags/android/chrome_feature_list.h
@@ -103,6 +103,7 @@ extern const base::Feature kRevampedContextMenu;
@@ -104,6 +104,7 @@ extern const base::Feature kRevampedContextMenu;
extern const base::Feature kScrollToExpandPaymentHandler;
extern const base::Feature kSearchEnginePromoExistingDevice;
extern const base::Feature kSearchEnginePromoNewDevice;

View file

@ -398,7 +398,7 @@ diff --git a/chrome/android/javatests/src/org/chromium/chrome/browser/sync/UkmTe
diff --git a/chrome/browser/ui/android/strings/android_chrome_strings.grd b/chrome/browser/ui/android/strings/android_chrome_strings.grd
--- a/chrome/browser/ui/android/strings/android_chrome_strings.grd
+++ b/chrome/browser/ui/android/strings/android_chrome_strings.grd
@@ -672,6 +672,18 @@ CHAR-LIMIT guidelines:
@@ -671,6 +671,18 @@ CHAR-LIMIT guidelines:
<message name="IDS_PREFS_PRIVACY" desc="Title for the Privacy preferences. [CHAR-LIMIT=32]">
Privacy
</message>
@ -417,7 +417,7 @@ diff --git a/chrome/browser/ui/android/strings/android_chrome_strings.grd b/chro
<message name="IDS_SAFE_BROWSING_SCOUT_REPORTING_TITLE" desc="Title for checkbox that controls reporting data to detect bad apps/sites. Please ensure Safe Browsing in this message matches the Safe Browsing settings title.">
Help improve Chrome security
</message>
@@ -1099,6 +1111,9 @@ Your Google account may have other forms of browsing history like searches and a
@@ -1098,6 +1110,9 @@ Your Google account may have other forms of browsing history like searches and a
<message name="IDS_ACCOUNT_MANAGEMENT_TITLE" desc="Header title for the account management screen. [CHAR-LIMIT=32]">
Signed in to Google as
</message>
@ -430,7 +430,7 @@ diff --git a/chrome/browser/ui/android/strings/android_chrome_strings.grd b/chro
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_am.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_am.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_am.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_am.xtb
@@ -994,4 +994,21 @@
@@ -1000,4 +1000,21 @@
<translation id="981121421437150478">ከመስመር ውጪ</translation>
<translation id="983192555821071799">ሁሉንም ትሮች ይዝጉ</translation>
<translation id="987264212798334818">አጠቃላይ</translation>
@ -457,7 +457,7 @@ diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strin
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_ar.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_ar.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_ar.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_ar.xtb
@@ -994,4 +994,21 @@
@@ -1000,4 +1000,21 @@
<translation id="981121421437150478">بلا اتصال</translation>
<translation id="983192555821071799">إغلاق جميع علامات التبويب</translation>
<translation id="987264212798334818">عام</translation>
@ -484,7 +484,7 @@ diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strin
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_bg.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_bg.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_bg.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_bg.xtb
@@ -994,4 +994,21 @@
@@ -1000,4 +1000,21 @@
<translation id="981121421437150478">Офлайн</translation>
<translation id="983192555821071799">Затваряне на всички раздели</translation>
<translation id="987264212798334818">Общи</translation>
@ -511,7 +511,7 @@ diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strin
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_bn.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_bn.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_bn.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_bn.xtb
@@ -996,4 +996,21 @@
@@ -1002,4 +1002,21 @@
<translation id="981121421437150478">অফলাইন</translation>
<translation id="983192555821071799">সমস্ত ট্যাবগুলি বন্ধ করুন</translation>
<translation id="987264212798334818">সাধারণ</translation>
@ -538,7 +538,7 @@ diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strin
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_ca.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_ca.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_ca.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_ca.xtb
@@ -994,4 +994,21 @@ Per exemple, és possible que alguns llocs web responguin a aquesta sol·licitud
@@ -1000,4 +1000,21 @@ Per exemple, és possible que alguns llocs web responguin a aquesta sol·licitud
<translation id="981121421437150478">Sense connexió</translation>
<translation id="983192555821071799">Tanca totes les pestanyes</translation>
<translation id="987264212798334818">General</translation>
@ -565,7 +565,7 @@ diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strin
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_cs.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_cs.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_cs.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_cs.xtb
@@ -994,4 +994,21 @@ Některé weby mohou například na tento požadavek reagovat tak, že vám zobr
@@ -1000,4 +1000,21 @@ Některé weby mohou například na tento požadavek reagovat tak, že vám zobr
<translation id="981121421437150478">Offline</translation>
<translation id="983192555821071799">Zavřít všechny karty</translation>
<translation id="987264212798334818">Všeobecné</translation>
@ -592,7 +592,7 @@ diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strin
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_da.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_da.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_da.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_da.xtb
@@ -994,4 +994,21 @@ Nogle websites kan f.eks. reagere på denne anmodning ved at vise dig annoncer,
@@ -1000,4 +1000,21 @@ Nogle websites kan f.eks. reagere på denne anmodning ved at vise dig annoncer,
<translation id="981121421437150478">Offline</translation>
<translation id="983192555821071799">Luk alle faner</translation>
<translation id="987264212798334818">Generelt</translation>
@ -619,7 +619,7 @@ diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strin
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_de.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_de.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_de.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_de.xtb
@@ -994,4 +994,21 @@ Einige Websites schalten möglicherweise Werbeanzeigen, deren Auswahl nicht dara
@@ -1000,4 +1000,21 @@ Einige Websites schalten möglicherweise Werbeanzeigen, deren Auswahl nicht dara
<translation id="981121421437150478">Offline</translation>
<translation id="983192555821071799">Alle Tabs schließen</translation>
<translation id="987264212798334818">Allgemein</translation>
@ -646,7 +646,7 @@ diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strin
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_el.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_el.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_el.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_el.xtb
@@ -994,4 +994,21 @@
@@ -1000,4 +1000,21 @@
<translation id="981121421437150478">Εκτός σύνδεσης</translation>
<translation id="983192555821071799">Κλείσιμο όλων των καρτελών</translation>
<translation id="987264212798334818">Γενικά</translation>
@ -673,7 +673,7 @@ diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strin
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_en-GB.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_en-GB.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_en-GB.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_en-GB.xtb
@@ -994,4 +994,21 @@ For example, some websites may respond to this request by showing you ads that a
@@ -1000,4 +1000,21 @@ For example, some websites may respond to this request by showing you ads that a
<translation id="981121421437150478">Offline</translation>
<translation id="983192555821071799">Close all tabs</translation>
<translation id="987264212798334818">General</translation>
@ -700,7 +700,7 @@ diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strin
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_es-419.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_es-419.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_es-419.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_es-419.xtb
@@ -994,4 +994,21 @@ Por ejemplo, algunos sitios web pueden responder a la solicitud mediante anuncio
@@ -1000,4 +1000,21 @@ Por ejemplo, algunos sitios web pueden responder a la solicitud mediante anuncio
<translation id="981121421437150478">Sin conexión</translation>
<translation id="983192555821071799">Cerrar todas las pestañas</translation>
<translation id="987264212798334818">General</translation>
@ -727,7 +727,7 @@ diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strin
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_es.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_es.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_es.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_es.xtb
@@ -994,4 +994,21 @@ Por ejemplo, algunos sitios web pueden responder a la solicitud mostrándote anu
@@ -1000,4 +1000,21 @@ Por ejemplo, algunos sitios web pueden responder a la solicitud mostrándote anu
<translation id="981121421437150478">Sin conexión</translation>
<translation id="983192555821071799">Cerrar todas las pestañas</translation>
<translation id="987264212798334818">General</translation>
@ -754,7 +754,7 @@ diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strin
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_et.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_et.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_et.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_et.xtb
@@ -994,4 +994,21 @@ Näiteks võivad mõned veebisaidid taotlusele reageerida nii, et näitavad teil
@@ -1000,4 +1000,21 @@ Näiteks võivad mõned veebisaidid taotlusele reageerida nii, et näitavad teil
<translation id="981121421437150478">Võrguühenduseta</translation>
<translation id="983192555821071799">Sule kõik vahelehed</translation>
<translation id="987264212798334818">Üldine</translation>
@ -781,7 +781,7 @@ diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strin
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_fa.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_fa.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_fa.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_fa.xtb
@@ -994,4 +994,21 @@
@@ -1000,4 +1000,21 @@
<translation id="981121421437150478">آفلاین</translation>
<translation id="983192555821071799">بستن همه برگه‌ها</translation>
<translation id="987264212798334818">موارد کلی</translation>
@ -808,7 +808,7 @@ diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strin
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_fi.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_fi.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_fi.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_fi.xtb
@@ -994,4 +994,21 @@ Jotkin verkkosivustot voivat vastata tähän pyyntöön esimerkiksi näyttämäl
@@ -1000,4 +1000,21 @@ Jotkin verkkosivustot voivat vastata tähän pyyntöön esimerkiksi näyttämäl
<translation id="981121421437150478">Offline</translation>
<translation id="983192555821071799">Sulje kaikki välilehdet</translation>
<translation id="987264212798334818">Yleistä</translation>
@ -835,7 +835,7 @@ diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strin
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_fil.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_fil.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_fil.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_fil.xtb
@@ -994,4 +994,21 @@ Halimbawa, puwedeng tumugon ang ilang website sa kahilingang ito sa pamamagitan
@@ -1000,4 +1000,21 @@ Halimbawa, puwedeng tumugon ang ilang website sa kahilingang ito sa pamamagitan
<translation id="981121421437150478">Offline</translation>
<translation id="983192555821071799">Isara ang lahat ng tab</translation>
<translation id="987264212798334818">Pangkalahatan</translation>
@ -862,7 +862,7 @@ diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strin
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_fr.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_fr.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_fr.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_fr.xtb
@@ -994,4 +994,21 @@ Par exemple, certains sites Web peuvent répondre à cette demande en diffusant
@@ -1000,4 +1000,21 @@ Par exemple, certains sites Web peuvent répondre à cette demande en diffusant
<translation id="981121421437150478">Hors connexion</translation>
<translation id="983192555821071799">Fermer tous les onglets</translation>
<translation id="987264212798334818">Général</translation>
@ -889,7 +889,7 @@ diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strin
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_gu.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_gu.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_gu.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_gu.xtb
@@ -994,4 +994,21 @@
@@ -1000,4 +1000,21 @@
<translation id="981121421437150478">ઑફલાઇન</translation>
<translation id="983192555821071799">બધા ટેબ્સ બંધ કરો</translation>
<translation id="987264212798334818">સામાન્ય</translation>
@ -916,7 +916,7 @@ diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strin
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_hi.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_hi.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_hi.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_hi.xtb
@@ -994,4 +994,21 @@
@@ -1000,4 +1000,21 @@
<translation id="981121421437150478">ऑफ़लाइन</translation>
<translation id="983192555821071799">सभी टैब बंद करें</translation>
<translation id="987264212798334818">सामान्य</translation>
@ -943,7 +943,7 @@ diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strin
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_hr.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_hr.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_hr.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_hr.xtb
@@ -994,4 +994,21 @@ Na primjer, neke web-lokacije na taj zahtjev mogu odgovoriti tako da vam prikaž
@@ -1000,4 +1000,21 @@ Na primjer, neke web-lokacije na taj zahtjev mogu odgovoriti tako da vam prikaž
<translation id="981121421437150478">Izvanmrežno</translation>
<translation id="983192555821071799">Zatvori sve kartice</translation>
<translation id="987264212798334818">Općenito</translation>
@ -970,7 +970,7 @@ diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strin
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_hu.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_hu.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_hu.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_hu.xtb
@@ -994,4 +994,21 @@ Egyes webhelyek például válaszolhatnak rá úgy, hogy olyan hirdetéseket jel
@@ -1000,4 +1000,21 @@ Egyes webhelyek például válaszolhatnak rá úgy, hogy olyan hirdetéseket jel
<translation id="981121421437150478">Offline</translation>
<translation id="983192555821071799">Az összes lap bezárása</translation>
<translation id="987264212798334818">Általános</translation>
@ -997,7 +997,7 @@ diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strin
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_id.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_id.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_id.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_id.xtb
@@ -994,4 +994,21 @@ Misalnya, beberapa situs web mungkin menanggapi permintaan ini dengan menayangka
@@ -1000,4 +1000,21 @@ Misalnya, beberapa situs web mungkin menanggapi permintaan ini dengan menayangka
<translation id="981121421437150478">Offline</translation>
<translation id="983192555821071799">Tutup semua tab</translation>
<translation id="987264212798334818">Umum</translation>
@ -1024,7 +1024,7 @@ diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strin
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_it.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_it.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_it.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_it.xtb
@@ -994,4 +994,21 @@ Ad esempio, alcuni siti web potrebbero rispondere alla richiesta mostrando annun
@@ -1000,4 +1000,21 @@ Ad esempio, alcuni siti web potrebbero rispondere alla richiesta mostrando annun
<translation id="981121421437150478">Offline</translation>
<translation id="983192555821071799">Chiudi tutte le schede</translation>
<translation id="987264212798334818">Generali</translation>
@ -1051,9 +1051,9 @@ diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strin
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_iw.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_iw.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_iw.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_iw.xtb
@@ -994,4 +994,21 @@
@@ -1000,4 +1000,21 @@
<translation id="981121421437150478">לא מקוון</translation>
<translation id="983192555821071799">סגור את כל הכרטיסיות</translation>
<translation id="983192555821071799">סגירת כל הכרטיסיות</translation>
<translation id="987264212798334818">כללי</translation>
-</translationbundle>
\ No newline at end of file
@ -1078,7 +1078,7 @@ diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strin
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_ja.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_ja.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_ja.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_ja.xtb
@@ -994,4 +994,21 @@
@@ -1000,4 +1000,21 @@
<translation id="981121421437150478">オフライン</translation>
<translation id="983192555821071799">すべてのタブを閉じる</translation>
<translation id="987264212798334818">全般</translation>
@ -1105,7 +1105,7 @@ diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strin
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_kn.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_kn.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_kn.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_kn.xtb
@@ -994,4 +994,21 @@
@@ -1000,4 +1000,21 @@
<translation id="981121421437150478">ಆಫ್‌ಲೈನ್</translation>
<translation id="983192555821071799">ಎಲ್ಲ ಟ್ಯಾಬ್‌ಗಳನ್ನು ಮುಚ್ಚಿ</translation>
<translation id="987264212798334818">ಸಾಮಾನ್ಯ</translation>
@ -1132,7 +1132,7 @@ diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strin
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_ko.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_ko.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_ko.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_ko.xtb
@@ -994,4 +994,21 @@
@@ -1000,4 +1000,21 @@
<translation id="981121421437150478">오프라인</translation>
<translation id="983192555821071799">탭 모두 닫기</translation>
<translation id="987264212798334818">일반</translation>
@ -1159,7 +1159,7 @@ diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strin
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_lt.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_lt.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_lt.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_lt.xtb
@@ -994,4 +994,21 @@ Pavyzdžiui, kai kurios svetainės gali atsakyti į šią užklausą rodydamos j
@@ -1000,4 +1000,21 @@ Pavyzdžiui, kai kurios svetainės gali atsakyti į šią užklausą rodydamos j
<translation id="981121421437150478">Neprisijungus</translation>
<translation id="983192555821071799">Uždar. visų skirtukų lapus</translation>
<translation id="987264212798334818">Bendra</translation>
@ -1186,7 +1186,7 @@ diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strin
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_lv.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_lv.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_lv.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_lv.xtb
@@ -994,4 +994,21 @@ Piemēram, dažas vietnes, reaģējot uz šo pieprasījumu, var rādīt jums rek
@@ -1000,4 +1000,21 @@ Piemēram, dažas vietnes, reaģējot uz šo pieprasījumu, var rādīt jums rek
<translation id="981121421437150478">Bezsaistē</translation>
<translation id="983192555821071799">Aizvērt visas cilnes</translation>
<translation id="987264212798334818">Vispārīgi</translation>
@ -1213,9 +1213,9 @@ diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strin
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_ml.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_ml.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_ml.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_ml.xtb
@@ -994,4 +994,21 @@
@@ -1000,4 +1000,21 @@
<translation id="981121421437150478">ഓഫ്‌ലൈൻ</translation>
<translation id="983192555821071799">എല്ലാ ടാബുകളും അടയ്‌ക്കുക</translation>
<translation id="983192555821071799">ടാബെല്ലാം അടയ്‌ക്കൂ</translation>
<translation id="987264212798334818">പൊതുവായ</translation>
-</translationbundle>
\ No newline at end of file
@ -1240,7 +1240,7 @@ diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strin
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_mr.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_mr.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_mr.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_mr.xtb
@@ -994,4 +994,21 @@
@@ -1000,4 +1000,21 @@
<translation id="981121421437150478">ऑफलाइन</translation>
<translation id="983192555821071799">सर्व टॅब बंद करा</translation>
<translation id="987264212798334818">सामान्य</translation>
@ -1267,7 +1267,7 @@ diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strin
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_ms.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_ms.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_ms.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_ms.xtb
@@ -994,4 +994,21 @@ Sebagai contoh, sesetengah tapak web mungkin memberi respons kepada permintaan i
@@ -1000,4 +1000,21 @@ Sebagai contoh, sesetengah tapak web mungkin memberi respons kepada permintaan i
<translation id="981121421437150478">Luar talian</translation>
<translation id="983192555821071799">Tutup semua tab</translation>
<translation id="987264212798334818">Umum</translation>
@ -1294,7 +1294,7 @@ diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strin
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_nl.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_nl.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_nl.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_nl.xtb
@@ -994,4 +994,21 @@ Zo kunnen sommige websites op dit verzoek reageren door advertenties weer te gev
@@ -1000,4 +1000,21 @@ Zo kunnen sommige websites op dit verzoek reageren door advertenties weer te gev
<translation id="981121421437150478">Offline</translation>
<translation id="983192555821071799">Alle tabbladen sluiten</translation>
<translation id="987264212798334818">Algemeen</translation>
@ -1321,7 +1321,7 @@ diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strin
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_no.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_no.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_no.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_no.xtb
@@ -994,4 +994,21 @@ Noen nettsteder kan for eksempel svare på denne forespørselen ved å vise deg
@@ -1000,4 +1000,21 @@ Noen nettsteder kan for eksempel svare på denne forespørselen ved å vise deg
<translation id="981121421437150478">Uten nett</translation>
<translation id="983192555821071799">Lukk alle faner</translation>
<translation id="987264212798334818">Generelt</translation>
@ -1348,7 +1348,7 @@ diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strin
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_pl.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_pl.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_pl.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_pl.xtb
@@ -994,4 +994,21 @@ Na przykład niektóre strony mogą na nie zareagować, wyświetlając reklamy b
@@ -1000,4 +1000,21 @@ Na przykład niektóre strony mogą na nie zareagować, wyświetlając reklamy b
<translation id="981121421437150478">Offline</translation>
<translation id="983192555821071799">Zamknij wszystkie karty</translation>
<translation id="987264212798334818">Ogólne</translation>
@ -1375,7 +1375,7 @@ diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strin
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_pt-BR.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_pt-BR.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_pt-BR.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_pt-BR.xtb
@@ -995,4 +995,21 @@ Por exemplo, alguns sites podem responder a esse pedido mostrando anúncios que
@@ -1001,4 +1001,21 @@ Por exemplo, alguns sites podem responder a esse pedido mostrando anúncios que
<translation id="981121421437150478">Off-line</translation>
<translation id="983192555821071799">Fechar todas as guias</translation>
<translation id="987264212798334818">Geral</translation>
@ -1402,7 +1402,7 @@ diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strin
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_pt-PT.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_pt-PT.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_pt-PT.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_pt-PT.xtb
@@ -994,4 +994,21 @@ Por exemplo, alguns Sites podem responder a este pedido ao mostrar-lhe anúncios
@@ -1000,4 +1000,21 @@ Por exemplo, alguns Sites podem responder a este pedido ao mostrar-lhe anúncios
<translation id="981121421437150478">Offline</translation>
<translation id="983192555821071799">Fechar todos os separadores</translation>
<translation id="987264212798334818">Geral</translation>
@ -1429,7 +1429,7 @@ diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strin
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_ro.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_ro.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_ro.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_ro.xtb
@@ -994,4 +994,21 @@ De exemplu, unele site-uri pot răspunde la această solicitare afișând anunț
@@ -1000,4 +1000,21 @@ De exemplu, unele site-uri pot răspunde la această solicitare afișând anunț
<translation id="981121421437150478">Offline</translation>
<translation id="983192555821071799">Închide toate filele</translation>
<translation id="987264212798334818">General</translation>
@ -1456,7 +1456,7 @@ diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strin
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_ru.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_ru.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_ru.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_ru.xtb
@@ -994,4 +994,21 @@
@@ -1000,4 +1000,21 @@
<translation id="981121421437150478">Офлайн</translation>
<translation id="983192555821071799">Закрыть все вкладки</translation>
<translation id="987264212798334818">Общие</translation>
@ -1483,7 +1483,7 @@ diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strin
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_sk.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_sk.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_sk.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_sk.xtb
@@ -994,4 +994,21 @@ Niektoré weby môžu napríklad na túto žiadosť reagovať tak, že vám zobr
@@ -1000,4 +1000,21 @@ Niektoré weby môžu napríklad na túto žiadosť reagovať tak, že vám zobr
<translation id="981121421437150478">Offline</translation>
<translation id="983192555821071799">Zavrieť všetky karty</translation>
<translation id="987264212798334818">Všeobecné</translation>
@ -1510,7 +1510,7 @@ diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strin
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_sl.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_sl.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_sl.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_sl.xtb
@@ -994,4 +994,21 @@ Nekatera spletna mesta se lahko na primer na zahtevo odzovejo tako, da prikažej
@@ -1000,4 +1000,21 @@ Nekatera spletna mesta se lahko na primer na zahtevo odzovejo tako, da prikažej
<translation id="981121421437150478">Brez povezave</translation>
<translation id="983192555821071799">Zapri vse zavihke</translation>
<translation id="987264212798334818">Splošno</translation>
@ -1537,7 +1537,7 @@ diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strin
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_sr.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_sr.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_sr.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_sr.xtb
@@ -994,4 +994,21 @@ Google налог можда има друге облике историје п
@@ -1000,4 +1000,21 @@ Google налог можда има друге облике историје п
<translation id="981121421437150478">Офлајн</translation>
<translation id="983192555821071799">Затвори све картице</translation>
<translation id="987264212798334818">Опште</translation>
@ -1564,7 +1564,7 @@ diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strin
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_sv.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_sv.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_sv.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_sv.xtb
@@ -994,4 +994,21 @@ Vissa webbplatser kan till exempel svara på begäran genom att visa annonser so
@@ -1000,4 +1000,21 @@ Vissa webbplatser kan till exempel svara på begäran genom att visa annonser so
<translation id="981121421437150478">Offline</translation>
<translation id="983192555821071799">Stäng alla flikar</translation>
<translation id="987264212798334818">Allmänt</translation>
@ -1591,7 +1591,7 @@ diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strin
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_sw.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_sw.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_sw.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_sw.xtb
@@ -994,4 +994,21 @@ Kwa mfano, baadhi ya tovuti zinaweza kujibu ombi hili kwa kukuonyesha matangazo
@@ -1000,4 +1000,21 @@ Kwa mfano, baadhi ya tovuti zinaweza kujibu ombi hili kwa kukuonyesha matangazo
<translation id="981121421437150478">Nje ya mtandao</translation>
<translation id="983192555821071799">Funga vichupo vyote</translation>
<translation id="987264212798334818">Jumla</translation>
@ -1618,7 +1618,7 @@ diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strin
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_ta.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_ta.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_ta.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_ta.xtb
@@ -994,4 +994,21 @@
@@ -1000,4 +1000,21 @@
<translation id="981121421437150478">ஆஃப்லைன்</translation>
<translation id="983192555821071799">எல்லா தாவல்களையும் மூடு</translation>
<translation id="987264212798334818">பொது</translation>
@ -1645,7 +1645,7 @@ diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strin
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_te.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_te.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_te.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_te.xtb
@@ -994,4 +994,21 @@
@@ -1000,4 +1000,21 @@
<translation id="981121421437150478">ఆఫ్‌లైన్</translation>
<translation id="983192555821071799">అన్ని ట్యాబ్‌లను మూసివేయి</translation>
<translation id="987264212798334818">సాధారణం</translation>
@ -1672,7 +1672,7 @@ diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strin
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_th.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_th.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_th.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_th.xtb
@@ -994,4 +994,21 @@
@@ -1000,4 +1000,21 @@
<translation id="981121421437150478">ออฟไลน์</translation>
<translation id="983192555821071799">ปิดแท็บทั้งหมด</translation>
<translation id="987264212798334818">ทั่วไป</translation>
@ -1699,7 +1699,7 @@ diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strin
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_tr.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_tr.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_tr.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_tr.xtb
@@ -994,4 +994,21 @@ Bu ayarı değiştirmek için <ph name="BEGIN_LINK" />senkronizasyonu sıfırlay
@@ -1000,4 +1000,21 @@ Bu ayarı değiştirmek için <ph name="BEGIN_LINK" />senkronizasyonu sıfırlay
<translation id="981121421437150478">Çevrimdışı</translation>
<translation id="983192555821071799">Tüm sekmeleri kapat</translation>
<translation id="987264212798334818">Genel</translation>
@ -1726,7 +1726,7 @@ diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strin
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_uk.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_uk.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_uk.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_uk.xtb
@@ -994,4 +994,21 @@
@@ -1000,4 +1000,21 @@
<translation id="981121421437150478">Офлайн</translation>
<translation id="983192555821071799">Закрити всі вкладки</translation>
<translation id="987264212798334818">Загальне</translation>
@ -1753,9 +1753,9 @@ diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strin
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_vi.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_vi.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_vi.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_vi.xtb
@@ -994,4 +994,21 @@ Ví dụ: một số trang web có thể phản hồi yêu cầu này bằng cá
@@ -1000,4 +1000,21 @@ Ví dụ: một số trang web có thể phản hồi yêu cầu này bằng cá
<translation id="981121421437150478">Ngoại tuyến</translation>
<translation id="983192555821071799">Đóng tất cả các tab</translation>
<translation id="983192555821071799">Đóng tất cả các thẻ</translation>
<translation id="987264212798334818">Chung</translation>
-</translationbundle>
\ No newline at end of file
@ -1780,7 +1780,7 @@ diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strin
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_zh-CN.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_zh-CN.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_zh-CN.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_zh-CN.xtb
@@ -994,4 +994,21 @@
@@ -1000,4 +1000,21 @@
<translation id="981121421437150478">离线</translation>
<translation id="983192555821071799">关闭所有标签页</translation>
<translation id="987264212798334818">常规</translation>
@ -1807,7 +1807,7 @@ diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strin
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_zh-TW.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_zh-TW.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_zh-TW.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_zh-TW.xtb
@@ -994,4 +994,21 @@
@@ -1000,4 +1000,21 @@
<translation id="981121421437150478">離線</translation>
<translation id="983192555821071799">關閉所有分頁</translation>
<translation id="987264212798334818">一般</translation>

View file

@ -24,7 +24,7 @@ diff --git a/chrome/app/resources/generated_resources_zh-CN.xtb b/chrome/app/res
diff --git a/chrome/browser/ui/android/strings/translations/android_chrome_strings_zh-CN.xtb b/chrome/browser/ui/android/strings/translations/android_chrome_strings_zh-CN.xtb
--- a/chrome/browser/ui/android/strings/translations/android_chrome_strings_zh-CN.xtb
+++ b/chrome/browser/ui/android/strings/translations/android_chrome_strings_zh-CN.xtb
@@ -1011,4 +1011,23 @@
@@ -1017,4 +1017,23 @@
<translation id="666268767214822976">当您在地址栏中输入查询内容时,使用联想查询服务显示相关查询和热门网站</translation>
<translation id="8283853025636624853">正在同步到 <ph name="SYNC_ACCOUNT_USER_NAME" /></translation>
<translation id="8981454092730389528">Google 活动控件</translation>

View file

@ -69,7 +69,7 @@ diff --git a/chrome/android/chrome_java_sources.gni b/chrome/android/chrome_java
"java/src/org/chromium/chrome/browser/ChromeBackupAgent.java",
"java/src/org/chromium/chrome/browser/ChromeBackupWatcher.java",
"java/src/org/chromium/chrome/browser/ChromeBaseAppCompatActivity.java",
@@ -1384,11 +1383,6 @@ chrome_java_sources = [
@@ -1387,11 +1386,6 @@ chrome_java_sources = [
"java/src/org/chromium/chrome/browser/services/AndroidChildAccountHelper.java",
"java/src/org/chromium/chrome/browser/services/AndroidEduOwnerCheckCallback.java",
"java/src/org/chromium/chrome/browser/services/GoogleServicesManager.java",
@ -107,7 +107,7 @@ diff --git a/chrome/android/java/AndroidManifest.xml b/chrome/android/java/Andro
<uses-permission android:name="com.android.launcher.permission.INSTALL_SHORTCUT"/>
{% block extra_uses_permissions %}
@@ -949,45 +944,6 @@ by a child template that "extends" this file.
@@ -955,45 +950,6 @@ by a child template that "extends" this file.
android:configChanges="orientation|keyboardHidden|keyboard|screenSize|mcc|mnc|screenLayout|smallestScreenSize"
android:hardwareAccelerated="false" />
@ -153,7 +153,7 @@ diff --git a/chrome/android/java/AndroidManifest.xml b/chrome/android/java/Andro
<!-- Android Notification service listener -->
<service android:name="org.chromium.chrome.browser.notifications.NotificationService"
android:exported="false"/>
@@ -1009,28 +965,10 @@ by a child template that "extends" this file.
@@ -1015,28 +971,10 @@ by a child template that "extends" this file.
android:exported="false"
android:permission="android.permission.BIND_JOB_SERVICE"/>

View file

@ -1,24 +0,0 @@
From: Jan Engelhardt <jengelh@inai.de>
Date: Sat, 13 Sep 2014 17:25:47 +0200
Subject: prefs: only keep cookies until exit
Out with all those tracking cookies!
---
.../content_settings/core/browser/content_settings_registry.cc | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
diff --git a/components/content_settings/core/browser/content_settings_registry.cc b/components/content_settings/core/browser/content_settings_registry.cc
--- a/components/content_settings/core/browser/content_settings_registry.cc
+++ b/components/content_settings/core/browser/content_settings_registry.cc
@@ -140,7 +140,7 @@ void ContentSettingsRegistry::Init() {
// WARNING: The string names of the permissions passed in below are used to
// generate preference names and should never be changed!
- Register(ContentSettingsType::COOKIES, "cookies", CONTENT_SETTING_ALLOW,
+ Register(ContentSettingsType::COOKIES, "cookies", CONTENT_SETTING_SESSION_ONLY,
WebsiteSettingsInfo::SYNCABLE,
WhitelistedSchemes(kChromeUIScheme, kChromeDevToolsScheme),
ValidSettings(CONTENT_SETTING_ALLOW, CONTENT_SETTING_BLOCK,
--
2.17.1

View file

@ -69,7 +69,7 @@ diff --git a/chrome/android/java/src/org/chromium/chrome/browser/language/settin
diff --git a/chrome/browser/ui/android/strings/android_chrome_strings.grd b/chrome/browser/ui/android/strings/android_chrome_strings.grd
--- a/chrome/browser/ui/android/strings/android_chrome_strings.grd
+++ b/chrome/browser/ui/android/strings/android_chrome_strings.grd
@@ -876,9 +876,6 @@ Your Google account may have other forms of browsing history like searches and a
@@ -875,9 +875,6 @@ Your Google account may have other forms of browsing history like searches and a
<message name="IDS_LANGUAGES_LIST_DESCRIPTION" desc="Description on the Languages settings screen. Appears above a list of one or more languages that the user selects, to tell Chrome which languages they prefer to use to read website content.">
Websites will show text in your preferred language, when possible.
</message>
diff --git a/components/browser_ui/site_settings/android/java/src/org/chromium/components/browser_ui/site_settings/SingleCategorySettings.java b/components/browser_ui/site_settings/android/java/src/org/chromium/components/browser_ui/site_settings/SingleCategorySettings.java
--- a/components/browser_ui/site_settings/android/java/src/org/chromium/components/browser_ui/site_settings/SingleCategorySettings.java
+++ b/components/browser_ui/site_settings/android/java/src/org/chromium/components/browser_ui/site_settings/SingleCategorySettings.java
@@ -132,6 +132,7 @@ public class SingleCategorySettings extends SiteSettingsPreferenceFragment
// Keys for category-specific preferences (toggle, link, button etc.), dynamically shown.
public static final String THIRD_PARTY_COOKIES_TOGGLE_KEY = "third_party_cookies";
+ public static final String COOKIES_SESSION_ONLY_TOGGLE_KEY = "cookies_session_only";
public static final String NOTIFICATIONS_VIBRATE_TOGGLE_KEY = "notifications_vibrate";
public static final String NOTIFICATIONS_QUIET_UI_TOGGLE_KEY = "notifications_quiet_ui";
public static final String EXPLAIN_PROTECTED_MEDIA_KEY = "protected_content_learn_more";
@@ -534,6 +535,7 @@ public class SingleCategorySettings extends SiteSettingsPreferenceFragment
if (type == SiteSettingsCategory.Type.COOKIES) {
updateThirdPartyCookiesCheckBox();
+ updateCookiesSessionOnlyCheckBox();
} else if (type == SiteSettingsCategory.Type.NOTIFICATIONS) {
updateNotificationsSecondaryControls();
}
@@ -550,6 +552,16 @@ public class SingleCategorySettings extends SiteSettingsPreferenceFragment
} else if (FOUR_STATE_COOKIE_TOGGLE_KEY.equals(preference.getKey())) {
setCookieSettingsPreference((CookieSettingsState) newValue);
getInfoForOrigins();
+ } else if (COOKIES_SESSION_ONLY_TOGGLE_KEY.equals(preference.getKey())) {
+ int setting;
+ if (((boolean) newValue)) {
+ setting = ContentSettingValues.SESSION_ONLY;
+ } else {
+ setting = isBlocked() ? ContentSettingValues.BLOCK
+ : ContentSettingValues.ALLOW;
+ }
+ WebsitePreferenceBridge.setContentSetting(
+ browserContextHandle, mCategory.getContentSettingsType(), setting);
} else if (THIRD_PARTY_COOKIES_TOGGLE_KEY.equals(preference.getKey())) {
getPrefs().setBlockThirdPartyCookies((boolean) newValue);
} else if (NOTIFICATIONS_VIBRATE_TOGGLE_KEY.equals(preference.getKey())) {
@@ -675,6 +687,11 @@ public class SingleCategorySettings extends SiteSettingsPreferenceFragment
if (mCategory.showSites(SiteSettingsCategory.Type.COOKIES) && mRequiresFourStateSetting) {
setting = cookieSettingsExceptionShouldBlock() ? ContentSettingValues.BLOCK
: ContentSettingValues.ALLOW;
+ ChromeBaseCheckBoxPreference cookiesSessionOnlyPref = (ChromeBaseCheckBoxPreference)
+ getPreferenceScreen().findPreference(COOKIES_SESSION_ONLY_TOGGLE_KEY);
+ if (cookiesSessionOnlyPref.isChecked() && (setting == ContentSettingValues.ALLOW)) {
+ setting = ContentSettingValues.SESSION_ONLY;
+ }
} else {
setting = (WebsitePreferenceBridge.isCategoryEnabled(
browserContextHandle, mCategory.getContentSettingsType()))
@@ -934,6 +951,8 @@ public class SingleCategorySettings extends SiteSettingsPreferenceFragment
(FourStateCookieSettingsPreference) screen.findPreference(
FOUR_STATE_COOKIE_TOGGLE_KEY);
Preference thirdPartyCookies = screen.findPreference(THIRD_PARTY_COOKIES_TOGGLE_KEY);
+ Preference cookiesSessionOnly = getPreferenceScreen().findPreference(
+ COOKIES_SESSION_ONLY_TOGGLE_KEY);
Preference notificationsVibrate = screen.findPreference(NOTIFICATIONS_VIBRATE_TOGGLE_KEY);
Preference notificationsQuietUi = screen.findPreference(NOTIFICATIONS_QUIET_UI_TOGGLE_KEY);
Preference explainProtectedMediaKey = screen.findPreference(EXPLAIN_PROTECTED_MEDIA_KEY);
@@ -976,6 +995,7 @@ public class SingleCategorySettings extends SiteSettingsPreferenceFragment
if (hideSecondaryToggles) {
screen.removePreference(thirdPartyCookies);
+ screen.removePreference(cookiesSessionOnly);
screen.removePreference(notificationsVibrate);
screen.removePreference(notificationsQuietUi);
screen.removePreference(explainProtectedMediaKey);
@@ -987,12 +1007,15 @@ public class SingleCategorySettings extends SiteSettingsPreferenceFragment
return;
}
// Configure/hide the third-party cookies toggle, as needed.
if (mCategory.showSites(SiteSettingsCategory.Type.COOKIES) && !mRequiresFourStateSetting) {
thirdPartyCookies.setOnPreferenceChangeListener(this);
updateThirdPartyCookiesCheckBox();
+ cookiesSessionOnly.setOnPreferenceChangeListener(this);
+ updateCookiesSessionOnlyCheckBox();
} else {
screen.removePreference(thirdPartyCookies);
+ screen.removePreference(cookiesSessionOnly);
}
// Configure/hide the notifications secondary controls, as needed.
@@ -1121,6 +1144,18 @@ public class SingleCategorySettings extends SiteSettingsPreferenceFragment
}
}
+ private void updateCookiesSessionOnlyCheckBox() {
+ BrowserContextHandle browserContextHandle =
+ getSiteSettingsClient().getBrowserContextHandle();
+ ChromeBaseCheckBoxPreference cookiesSessionOnlyPref = (ChromeBaseCheckBoxPreference)
+ getPreferenceScreen().findPreference(COOKIES_SESSION_ONLY_TOGGLE_KEY);
+ cookiesSessionOnlyPref.setChecked(
+ WebsitePreferenceBridge.getContentSetting(
+ browserContextHandle, mCategory.getContentSettingsType()) == ContentSettingValues.SESSION_ONLY);
+ cookiesSessionOnlyPref.setEnabled(WebsitePreferenceBridge.isCategoryEnabled(browserContextHandle,
+ ContentSettingsType.COOKIES));
+ }
+
private void updateThirdPartyCookiesCheckBox() {
ChromeBaseCheckBoxPreference thirdPartyCookiesPref =
(ChromeBaseCheckBoxPreference) getPreferenceScreen().findPreference(
@@ -987,12 +1007,15 @@ public class SingleCategorySettings extends SiteSettingsPreferenceFragment
return;
}
- // Configure/hide the third-party cookies toggle, as needed.
+ // Configure/hide the third-party cookies toggle and session-only cookie toggle, as needed.
if (mCategory.showSites(SiteSettingsCategory.Type.COOKIES) && !mRequiresFourStateSetting) {
thirdPartyCookies.setOnPreferenceChangeListener(this);